@@ -120,7 +120,9 @@ def validations(
     for validation in validations:
         console.print("Asset type: %s" % validation.manifest.asset_type)
         validation_dict = from_AssetValidationResult(validation)
-        validation_dict.pop(manifest)  # don't display, manifest...TODO do this better?
+        validation_dict.pop(
+            "manifest"
+        )  # don't display, manifest...TODO do this better?
         console.print(validation_dict)
 
 
